@@ -1,7 +1,7 @@
 ;;; ediff-help.el --- Code related to the contents of Ediff help buffers
 
 ;; Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-;;   2004, 2005, 2006, 2007 Free Software Foundation, Inc.
+;;   2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Michael Kifer <kifer@cs.stonybrook.edu>
 
@@ -33,7 +33,7 @@
 (eval-when-compile
   (let ((load-path (cons (expand-file-name ".") load-path)))
     (or (featurep 'ediff-init)
-	(load "ediff-init.el" nil nil 'nosuffix))
+	(load "ediff-init.el" nil t 'nosuffix))
     ))
 ;; end pacifier
 
@@ -165,7 +165,7 @@ the value of this variable and the variables `ediff-help-message-*' in
 
 (define-key
   ediff-help-region-map
-  (if ediff-emacs-p [mouse-2] [button2])
+  (if (featurep 'emacs) [mouse-2] [button2])
   'ediff-help-for-quick-help)
 
 ;; runs in the control buffer
@@ -177,7 +177,7 @@ the value of this variable and the variables `ediff-help-message-*' in
 	    end (match-end 0)
 	    cmd (buffer-substring (match-beginning 1) (match-end 1)))
       (setq overl (ediff-make-overlay beg end))
-      (if ediff-emacs-p
+      (if (featurep 'emacs)
 	  (ediff-overlay-put overl 'mouse-face 'highlight)
 	(ediff-overlay-put overl 'highlight t))
       (ediff-overlay-put overl 'ediff-help-info cmd))))
